instrument
==========

`instrument <http://github.com/wearpants/instrument>`__ provides instrumentation primitives for metrics and benchmarking.

Python `Instrument` was formerly known as `Measure It`.

:author: Pete Fein <pete@wearpants.org>
:license: BSD
:versions: Python 2.7 & 3
:source: https://github.com/wearpants/instrument
:homepage: https://instrument.readthedocs.org/en/latest/

.. toctree::
    :maxdepth: 2

    installation
    basic_use
    output
    api
    incompatibilities
    future
    changelog
